@@ -1,10 +1,11 @@
 package CPAN::Testers::Data::Addresses;
 
+use 5.006;
 use strict;
 use warnings;
 
 use vars qw($VERSION);
-$VERSION = '0.03';
+$VERSION = '0.04';
 $|++;
 
 #----------------------------------------------------------------------------
@@ -852,13 +853,13 @@ http://rt.cpan.org/Public/Dist/Display.html?Name=CPAN-Testers-Data-Addresses
 
 =head1 SEE ALSO
 
-L<CPAN::Testers::Common::Article>,
-L<CPAN::Testers::Common::DBUtils>,
-L<CPAN::Testers::Data::Generate>
+L<CPAN::Testers::Data::Generator>,
+L<CPAN::Testers::WWW::Statistics>
 
 F<http://www.cpantesters.org/>,
 F<http://stats.cpantesters.org/>,
-F<http://wiki.cpantesters.org/>
+F<http://wiki.cpantesters.org/>,
+F<http://blog.cpantesters.org/>
 
 =head1 AUTHOR
 
